package RPM::Source::Transformation::Component::GirarNMU::Options;

use strict;
use warnings;
use Exporter 'import';
use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;
push @RPM::Source::TransformContainer::SUPPORT_CLASSES, __PACKAGE__;

our $verbose=0;
our $gitbranch='nmu';
our $origin_repo='sisyphus';
our $outgeardir='OUT.gits';
our $outsrpmdir='OUT.SRPMS';
our $opt_use_named_subtree_srpms=1;

my $GITERY_HOST;
our @_GITERY_ARGS;
our $_GITERY_ARGS='';

our @EXPORT_OK = qw($gitbranch $origin_repo $outgeardir $outsrpmdir @_GITERY_ARGS $_GITERY_ARGS);

sub print_longopt {
    print "  Name2Spec GirarNMU resolver input options:
    --originbranch <branch> default is sisyphus
    --H|--gitery|--git.alt GITERY_HOST
    --G|--outgear <dir> default is OUT.gits
    --S|--outsrpm <dir> default is OUT.SRPMS
    --d|localbranch|local-git-branch <name> optional check
    --indir/srpmdir /path to srpms (optional)
";
}
our @LONGOPT=(
#	"b|branch=s"   => \$origin_repo,
	"originbranch=s"   => \$origin_repo,
	"d|localbranch|local-git-branch=s"   => \$gitbranch,
	"H|gitery|git.alt=s"   => \$GITERY_HOST,
	"S|outsrpm=s"   => \$outsrpmdir,
	"G|outgear=s"   => \$outgeardir,
    );

sub process_options {
    if ($GITERY_HOST) {
	push @_GITERY_ARGS, '--gitery', $GITERY_HOST;
	$_GITERY_ARGS="--gitery '".$GITERY_HOST."'";
    }
}

1;
__END__

=pod

=head1	CLI EXPORT SYNOPSIS

[B<-b> I<repository>]
[B<-d> I<local branch>]
[B<-H|--gitery> I<ssh gitery alias>]
[B<-G> I<path/to/OUT.gits dir>]
[B<-S> I<path/to/OUT.SRPMS dir>]

=head1	CLI EXPORT OPTIONS

=head2	CLI EXPORT OPTIONS Input options

=over

=item	B<--originbranch> I<repository name>

Name of the repository branch. Values are: sisyphus|5.1|p8|..
Default is sisyphus.

=item	B<-d> I<local branch name>

Git repository option.
Name of the local git branch to build from. Default is nmu.

=item	B<-H|--gitery> [I<gitery ssh alias>]

By default, gitery.altlinux.org account should be configured as gitery in ~/.ssh/config.
If you do not follow that convention, use -H <your gitery ssh alias> option.

=back

=head2	CLI EXPORT OPTIONS Output options

=over

=item	B<-G> I<dir>

name of output directory with Git repositories.
Default is "OUT.gits".

=item	B<-S> I<dir>

name of output directory for src.rpms.
Default is "OUT.SRPMS".

=back

=cut

