package RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::OutGear;

use strict;
use warnings;

use Cwd qw/abs_path cwd/;
use File::Path qw(make_path remove_tree);
use Gear::Rules 0.197;

use RPM::Source::Transformation::Component::InputNameCommon;
use RPM::Source::Transformation::EarlyResource::GearRules;
use RPM::Source::Transformation::RPMEditorProvider;
use RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch;
use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;
$RPM::Source::TransformContainer::Name2SpecProvider=__PACKAGE__;
$RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch::GEAR_NAME2SPEC_PROVIDER=__PACKAGE__;

use RPM::Source::Transformation::Component::GirarNMU::Options 
    qw/$outgeardir $origin_repo $gitbranch @_GITERY_ARGS/;

our $verbose=1;

sub name2spec {
    my (undef,$name,$converter_opt,$resourceobj)=@_;
    my $curdir=cwd();
    print STDERR "OutGear: curdir=$curdir\n" if $verbose>1;
    -d $outgeardir || make_path($outgeardir);
    chdir $outgeardir;
    my @clone_args=('-f',@_GITERY_ARGS);
    push @clone_args, '-b',$origin_repo if $origin_repo;
    push @clone_args, '-d',$gitbranch if $gitbranch;
    &run('girar-clone-build-commit',@clone_args,$name);
    my $gearname=$name;
    chdir $gearname.'.git' || die "$!: can't chdir to cloned ${gearname}.git";
    my $rules=Gear::Rules->new();
    $resourceobj->set_cached_gear_rules($rules);
    my $specfile=$rules->get_spec();
    die "spec file not found" unless $specfile;
    $converter_opt->{-name2spec_provided_nvr}=join('-',$rules->get_nvr());
    
    my $spec=$RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec([
	GEARDIR => abs_path('.'),
	SPECFILE=> abs_path($specfile),
    ]);
    die "Oops! empty GEARDIR" unless defined $spec->{GEARDIR};
    chdir $curdir;
    return $spec;
}

sub run {
    print STDERR "running: ", join(' ',@_),"\n" if $verbose;
    system(@_)==0 or die "command failed: ".join(' ',@_);
}

1;
