package RPM::Source::Transformation::Provider::Name2Spec::GirarNMU::Switch;

use strict;
use warnings;

use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;

$RPM::Source::TransformContainer::Name2SpecProvider=__PACKAGE__;

our $GEAR_NAME2SPEC_PROVIDER;
our $SRPM_NAME2SPEC_PROVIDER;
sub cli_container_ref {
    return [$GEAR_NAME2SPEC_PROVIDER, $SRPM_NAME2SPEC_PROVIDER];
}

our $verbose=0;
our $opt_girar_upload_method;

use RPM::Source::Transformation::Component::GirarNMU::Options qw/$origin_repo $_GITERY_ARGS/;

sub print_longopt {
    print "  Input options:
    --girar-upload-method (srpm|git|auto) force girar upload method.
";
}

our @LONGOPT=(
	"girar-upload-method|upload-method=s"   => \$opt_girar_upload_method,
    );

sub process_options {
    if (not $GEAR_NAME2SPEC_PROVIDER or not $SRPM_NAME2SPEC_PROVIDER) {
	die "Internal error: Name2Spec::GirarNMU::Switch: missing provider";
    }
    $opt_girar_upload_method=undef if $opt_girar_upload_method and $opt_girar_upload_method eq 'auto';
    die "Invalid --girar-upload-method=$opt_girar_upload_method\n" if $opt_girar_upload_method and ($opt_girar_upload_method ne 'git' and $opt_girar_upload_method ne 'srpm');
}

sub register_messages {
    my ($self,$extopt)=@_;
    RPM::Source::Transformation::Component::add_opt($extopt, {
	-opt_girar_upload_method => $opt_girar_upload_method,
    });
}

sub name2spec {
    my ($class,$name,$converter_opt,$resourceobj)=@_;
    my $method=$converter_opt->{-opt_girar_upload_method};
    unless ($method) {
	$method=`girar-get-upload-method -b $origin_repo $_GITERY_ARGS '$name'`;
	chomp $method;
	$converter_opt->{-opt_girar_upload_method}=$method;
    }
    if ($method eq 'git') {
	return $GEAR_NAME2SPEC_PROVIDER->name2spec($name,$converter_opt,$resourceobj);
    } elsif ($method eq 'srpm') {
	return $SRPM_NAME2SPEC_PROVIDER->name2spec($name,$converter_opt,$resourceobj);
    } else {
	die "internal error: $method in girar-get-upload-method $name. Please, report.";
    }
}

1;
